@@ -1,10 +1,8 @@
-/*
- * SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
- * SPDX-License-Identifier: BSD-2-Clause
- */
+// SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+// SPDX-License-Identifier: BSD-2-Clause
 //! Check whether the program's features satisfy the specified condition.
 
-#![allow(clippy::pub_use)]
+#![expect(clippy::pub_use, reason = "re-export commonly used symbols")]
 
 use std::cmp::Ordering;
 use std::collections::HashMap;
@@ -177,11 +175,10 @@ pub fn parse(expr: &str) -> Result<Mode, ParseError> {
 
 #[cfg(test)]
 mod tests {
-    #![allow(clippy::panic)]
-    #![allow(clippy::panic_in_result_fn)]
-    #![allow(clippy::unwrap_used)]
-    #![allow(clippy::use_debug)]
-    #![allow(clippy::wildcard_enum_match_arm)]
+    #![expect(clippy::panic, reason = "this is a test suite")]
+    #![expect(clippy::panic_in_result_fn, reason = "this is a test suite")]
+    #![expect(clippy::unwrap_used, reason = "this is a test suite")]
+    #![expect(clippy::wildcard_enum_match_arm, reason = "this is a test suite")]
 
     use std::collections::HashMap;
     use std::error::Error;
@@ -189,7 +186,7 @@ mod tests {
     use crate::defs::{CalcResult, Mode};
 
     #[test]
-    fn test_parse_mode_simple_sign_no_space() -> Result<(), Box<dyn Error>> {
+    fn parse_mode_simple_sign_no_space() -> Result<(), Box<dyn Error>> {
         let mode = super::parse("hello<3.1")?;
         let res = match mode {
             Mode::Simple(res) => res,
@@ -198,17 +195,17 @@ mod tests {
         match res.get_value(&HashMap::from([("hello".to_owned(), "2".parse()?)]))? {
             CalcResult::Bool(true) => (),
             other => panic!("{other:?}"),
-        };
+        }
         match res.get_value(&HashMap::from([("hello".to_owned(), "4".parse()?)]))? {
             CalcResult::Bool(false) => (),
             other => panic!("{other:?}"),
-        };
+        }
         res.get_value(&HashMap::new()).unwrap_err();
         Ok(())
     }
 
     #[test]
-    fn test_parse_mode_simple_sign_space() -> Result<(), Box<dyn Error>> {
+    fn parse_mode_simple_sign_space() -> Result<(), Box<dyn Error>> {
         let mode = super::parse("hello < 3.1")?;
         let res = match mode {
             Mode::Simple(res) => res,
@@ -217,17 +214,17 @@ mod tests {
         match res.get_value(&HashMap::from([("hello".to_owned(), "2".parse()?)]))? {
             CalcResult::Bool(true) => (),
             other => panic!("{other:?}"),
-        };
+        }
         match res.get_value(&HashMap::from([("hello".to_owned(), "4".parse()?)]))? {
             CalcResult::Bool(false) => (),
             other => panic!("{other:?}"),
-        };
+        }
         res.get_value(&HashMap::new()).unwrap_err();
         Ok(())
     }
 
     #[test]
-    fn test_parse_mode_simple_word() -> Result<(), Box<dyn Error>> {
+    fn parse_mode_simple_word() -> Result<(), Box<dyn Error>> {
         let mode = super::parse("hello lt 3.1")?;
         let res = match mode {
             Mode::Simple(res) => res,
@@ -236,17 +233,17 @@ mod tests {
         match res.get_value(&HashMap::from([("hello".to_owned(), "2".parse()?)]))? {
             CalcResult::Bool(true) => (),
             other => panic!("{other:?}"),
-        };
+        }
         match res.get_value(&HashMap::from([("hello".to_owned(), "4".parse()?)]))? {
             CalcResult::Bool(false) => (),
             other => panic!("{other:?}"),
-        };
+        }
         res.get_value(&HashMap::new()).unwrap_err();
         Ok(())
     }
 
     #[test]
-    fn test_parse_mode_single() -> Result<(), Box<dyn Error>> {
+    fn parse_mode_single() -> Result<(), Box<dyn Error>> {
         let mode = super::parse("hello")?;
         let res = match mode {
             Mode::Single(res) => res,
@@ -255,11 +252,11 @@ mod tests {
         match res.get_value(&HashMap::from([("hello".to_owned(), "2".parse()?)]))? {
             CalcResult::Version(ver) => assert_eq!(ver.as_ref(), "2"),
             other => panic!("{other:?}"),
-        };
+        }
         match res.get_value(&HashMap::new())? {
             CalcResult::Null => (),
             other => panic!("{other:?}"),
-        };
+        }
         Ok(())
     }
 }
